pytilities.geometry._vectorbase — Pytilities v1.0.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities v1.0.0 documentation »
- API documentation »
- pytilities »
- pytilities.geometry »

# pytilities.geometry._vectorbase

class `pytilities.geometry._vectorbase.` `_VectorBase`(*args, **kwargs)

  Note to inheritors: you should provide an _x property on your class

  `_VectorBase__assign_v`(v)

    Assigns the values of another vector to this vector

    Parameters: | x (number) – x coordinate y (number) – y coordinate

  `_VectorBase__assign_xy`(x, y)

    Assigns the values to this vector

    Parameters: | x (number) – x coordinate y (number) – y coordinate

  `_VectorBase__init_bound_properties`(x_property, y_property)
  `_VectorBase__init_xy`(x, y)
  `__add__`(*args, **kwargs)
  `__copy__`(*args, **kwargs)
  `__delattr__`(*args, **kwargs)
  `__eq__`(*args, **kwargs)
  `__floordiv__`(*args, **kwargs)
  `__getattr__`(*args, **kwargs)
  `__getattribute__`(*args, **kwargs)
  `__getitem__`(*args, **kwargs)
  `__hash__`()
  `__iadd__`(*args, **kwargs)
  `__ifloordiv__`(*args, **kwargs)
  `__imul__`(*args, **kwargs)
  `__init__`(*args, **kwargs)
  `__isub__`(*args, **kwargs)
  `__iter__`(*args, **kwargs)
  `__len__`(*args, **kwargs)
  `__mul__`(*args, **kwargs)
  `__ne__`(*args, **kwargs)
  `__neg__`(*args, **kwargs)
  `__pos__`(*args, **kwargs)
  `__rfloordiv__`(*args, **kwargs)
  `__rmul__`(*args, **kwargs)
  `__setattr__`(*args, **kwargs)
  `__setitem__`(*args, **kwargs)
  `__str__`(*args, **kwargs)
  `__sub__`(*args, **kwargs)
  `_get_vector_operator`(other)

    Get instance for operator thingy. discrete op vector = vector

  `assign`(*args, **kwargs)
  `copy`(*args, **kwargs)
  `move_by`(*args, **kwargs)
  `move_to`(*args, **kwargs)
  `__weakref__`

    list of weak references to the object (if defined)

  `_x`

    Read-write, x position

  `_y`

    Read-write, y position

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities v1.0.0 documentation »
- API documentation »
- pytilities »
- pytilities.geometry »